@@ -1,7 +1,21 @@
 from .parsetable import GetNumberOfInputs
 from .parsetree import normalise_neighbourhood
 
-def NodesToCode(nhood, nodes, is16bit):
+
+def MakeStaticTable(nodes):
+
+    # Write rule tree in .data segment of the program:
+    lines = ["const static uint32_t __ruletree[] __attribute__((aligned(64))) = {\n"]
+    for (i, l) in enumerate(nodes):
+        body = '    ' + (','.join([('%du' % x) for x in l]))
+        body += ('};\n\n' if (i == len(nodes) - 1) else ',\n')
+        lines.append(body)
+    lines.append('\n')
+
+    return lines
+
+
+def NodesToCode(nhood, is16bit):
 
     numInputs = GetNumberOfInputs(nhood)
     numOutputs = len(nhood) - numInputs
@@ -22,16 +36,8 @@ def NodesToCode(nhood, nodes, is16bit):
     if is16bit:
         out_offsets += [t + 256 for t in out_offsets]
 
-    # Write rule tree in .data segment of the program:
-    lines = ["const static uint32_t __ruletree[] __attribute__((aligned(64))) = {\n"]
-    for (i, l) in enumerate(nodes):
-        body = '    ' + (','.join([('%du' % x) for x in l]))
-        body += ('};\n\n' if (i == len(nodes) - 1) else ',\n')
-        lines.append(body)
-    lines.append('\n')
-
     # Hopefully simple enough to vectorise:
-    lines.append('void iterate_var_row(uint8_t* __restrict__ inrow, uint8_t* __restrict__ outrow) {\n')
+    lines = ['void iterate_var_row(uint8_t* __restrict__ inrow, uint8_t* __restrict__ outrow) {\n']
     lines.append('    uint32_t temprow[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};\n')
     for offset in in_offsets:
         if (is16bit):
@@ -47,7 +53,4 @@ def NodesToCode(nhood, nodes, is16bit):
     lines.append('}\n')
     lines.append('\n')
 
-    # We have implemented iterate_var_row instead of iterate_var_grid:
-    lines.append('#include "row_based_approach.h"\n')
-
     return lines
