@@ -139,7 +139,7 @@ namespace apg {
                 kiventry<LK, I, LV>* pptr = leaves.ind2ptr(parent.index);
                 if (pptr->gcflags == 0) {
                     // if (outfile) {(*outfile) << 'L' << ':' << pptr->key.toBase85() << '\n';}
-                    pptr->gcflags = (++leaves.gccounter);
+                    pptr->gcflags = leaves.increment_gccounter();
                 }
                 return pptr->gcflags;
             } else {
@@ -150,7 +150,7 @@ namespace apg {
                         children.x[i] = gc_mark(mindepth, hypernode<I>(pptr->key.x[i], parent.depth-1));
                     }
                     // if (outfile) {(*outfile) << 'N' << parent.depth << ':' << children.toBase85() << '\n';}
-                    pptr->gcflags = (++(nonleaves[parent.depth-1]->gccounter));
+                    pptr->gcflags = nonleaves[parent.depth-1]->increment_gccounter();
                 }
                 return pptr->gcflags;
             }
@@ -160,14 +160,16 @@ namespace apg {
 
             uint64_t origbytes = total_bytes();
 
-            if (origbytes > 1000000000) {
+            bool verbose = (origbytes > 1500000000);
+
+            if (verbose) {
                 std::cerr << "Applying garbage collection from level " << mindepth << " upwards:" << std::endl;
                 std::cerr << " -- emptying tree..." << std::endl;
             }
 
             gc_traverse<false>(mindepth);
 
-            if (origbytes > 1000000000) {
+            if (verbose) {
                 std::cerr << " -- marking important nodes..." << std::endl;
             }
 
@@ -178,13 +180,13 @@ namespace apg {
                 gc_mark(mindepth, kv.second);
             }
 
-            if (origbytes > 1000000000) {
+            if (verbose) {
                 std::cerr << " -- removing surplus nodes..." << std::endl;
             }
 
             gc_traverse<true>(mindepth);
 
-            if (origbytes > 1000000000) {
+            if (verbose) {
                 uint64_t newbytes = total_bytes();
                 std::cerr << " -- completed." << std::endl;
                 std::cerr << "Hypertree memory reduced from " << origbytes << " to " << newbytes << " bytes." << std::endl;
