@@ -149,6 +149,14 @@ extern "C"
         return new(std::nothrow) apg::pattern(lab, std::string(filename));
     }
 
+    void* CreatePatternFromFileContents(void* lt, const char *contents) {
+        auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
+        std::string rule = "b3s23";
+        std::stringstream ss(contents);
+        apg::hypernode<uint32_t> hnode = lab->read_macrocell(ss, rule, 0);
+        return new(std::nothrow) apg::pattern(lab, hnode, std::string(rule));
+    }
+
     void* CreateRectangle(void* lt, int x, int y, int width, int height, const char *rule) {
         auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
         auto hnode = lab->rectangle(x, y, width, height);
