@@ -23,7 +23,7 @@ def get_symmetries(rulestring):
                         "D2_+2", "D2_+1", "D2_x", "D4_+4", "D4_+2", "D4_+1", "D4_x4", "D4_x1", "D8_4", "D8_1", "D2_+1_gO1s0", "D2_+1_gO1s1", "D2_+1_gO1s2"]
 
     if (re.match('^b0?1?2?3?4?5?6?7?8?s0?1?2?3?4?5?6?7?8?$', rulestring)):
-        validsyms += ["G1", "H2_+1", "H2_+2", "H4_+1", "H4_+2", "H4_+4"] # GPU symmetries
+        validsyms += ["G1", "G2_1", "G2_2", "G2_4", "H2_+1", "H2_+2", "H4_+1", "H4_+2", "H4_+4"] # GPU symmetries
 
     return validsyms
 
