@@ -61,3 +61,10 @@ for testtype in "unit" "integration" "indirection"; do
         "$python_name" -m unittest discover "lifelib/tests/$testtype"
     done
 done
+
+printf "\n\033[1;36m **** segfault tests ****\033[0m\n"
+for python_name in "${pythons[@]}"; do
+    "$python_name" -c 'import lifelib; lt = lifelib.load_rules("b3s23").lifetree(); pat = lt.pattern(); f = lambda x : x'
+done
+
+printf "\n\033[1mAll tests completed successfully.\033[0m\n"
